.. image:: https://img.shields.io/pypi/v/stdlib-utils.svg
    :target: https://pypi.org/project/stdlib-utils/

.. image:: https://pepy.tech/badge/stdlib-utils
  :target: https://pepy.tech/project/stdlib-utils

.. image:: https://img.shields.io/pypi/pyversions/stdlib-utils.svg
    :target: https://pypi.org/project/stdlib-utils/

.. image:: https://github.com/CuriBio/stdlib-utils/workflows/Dev/badge.svg?branch=development
   :alt: Development Branch Build

.. image:: https://codecov.io/gh/CuriBio/stdlib-utils/branch/development/graph/badge.svg
  :target: https://codecov.io/gh/CuriBio/stdlib-utils

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/psf/black

.. image:: https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white
   :target: https://github.com/pre-commit/pre-commit
   :alt: pre-commit